@@ -3,7 +3,7 @@ import asyncio
 from argparse_addons import Integer
 
 from ..client import Client
-from ..common import hexlify
+from . import format_message
 
 
 async def subscriber(host,
@@ -13,7 +13,9 @@ async def subscriber(host,
                      client_id,
                      topic,
                      keep_alive_s,
-                     session_expiry_interval):
+                     session_expiry_interval,
+                     retain_handling,
+                     message_format):
     if cafile:
         print(f"CA File:  '{cafile}'")
         print(f"Check hostname: {check_hostname}")
@@ -28,7 +30,7 @@ async def subscriber(host,
                     client_id,
                     keep_alive_s=keep_alive_s,
                     session_expiry_interval=session_expiry_interval,
-                    subscriptions=[topic],
+                    subscriptions=[(topic, retain_handling)],
                     topic_alias_maximum=10,
                     ssl=context)
 
@@ -45,7 +47,7 @@ async def subscriber(host,
                 break
 
             print(f'Topic:   {topic}')
-            print(f'Message: {hexlify(message)}')
+            print(f'Message: {format_message(message_format, message)}')
 
         await client.stop()
 
@@ -58,7 +60,9 @@ def _do_subscribe(args):
                            args.client_id,
                            args.topic,
                            args.keep_alive,
-                           args.session_expiry_interval))
+                           args.session_expiry_interval,
+                           args.retain_handling,
+                           args.message_format))
 
 
 def add_subparser(subparsers):
@@ -73,17 +77,27 @@ def add_subparser(subparsers):
                            help='Broker port (default: %(default)s).')
     subparser.add_argument('--client-id',
                            help='Client id (default: mqttools-<UUID[0..14]>).')
-    subparser.add_argument('--keep-alive',
-                           type=Integer(0),
-                           default=0,
-                           help=('Keep alive time in seconds (default: '
-                                 '%(default)s). Give as 0 to disable keep '
-                                 'alive.'))
+    subparser.add_argument(
+        '--keep-alive',
+        type=Integer(0),
+        default=0,
+        help=('Keep alive time in seconds (default: %(default)s). Give as 0 to '
+              'disable keep alive.'))
     subparser.add_argument(
         '--session-expiry-interval',
         default=0,
         type=Integer(0, 0xffffffff),
         help='Session expiry interval in the range 0..0xffffffff (default: %(default)s).')
+    subparser.add_argument(
+        '--retain-handling',
+        type=Integer(0, 2),
+        default=0,
+        help='Retain handling for the subscriptions (default: %(default)s).')
+    subparser.add_argument(
+        '--message-format',
+        choices=('auto', 'binary', 'text'),
+        default='auto',
+        help='Message format (default: %(default)s).')
     subparser.add_argument(
         '--cafile',
         default='',
